#!/usr/bin/perl
use lib '/home/erealms/ethereal/mgmt/perl';

#################################################################################
# Created       : Martin Foster
# Modified      : 29-Mar-2007
#################################################################################
#
# Short - Handles all of the short requirements for a name
# Copyright (C) 2000-2007  Martin Foster
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
# Author of this script can be contacted at the following:
#       E-Mail  : martin@ethereal-realms.org
#       Address : 4-3526 Wolfe Cres
#                 Halifax, Nova Scotia
#                 B3L 3S2
#
#################################################################################

use strict;							# Strict variable enforcement

use Ethereal::Database;						# Database handler


#################################################################################
# Data Members
#################################################################################
my $database;							# Database handle

my $res;							# Result handle
my $statement;							# Query

my $site;							# Site schema
my $short;							# Short name

#################################################################################
# Program Area
#################################################################################

	# Make sure schema is specified
	if ($site = shift(@ARGV))
	{
		# Initial handles
		$database = new Ethereal::Database();

		# Connect and Fetch
		$database->Connect();
	
		# Set search paths
		$database->Write("SET SEARCH_PATH TO $site,public");


		# Puppet handler
		print "\n--PUPPET--\n\n";
		# Look for entries without short names
		$database->Pull(\$statement, "SELECT
			  PuppetName AS \"PuppetName\",
			  PuppetPool AS \"PuppetPool\"
			FROM Puppet
			WHERE PuppetShort IS NULL");

		# Loop through
		while ($res = $statement->fetchrow_hashref())
		{
			# Display
			print "    " . $res->{'PuppetPool'} . '/' . $res->{'PuppetName'} . "\n";

			# Generate short name
			$short  =  lc($res->{'PuppetName'});
			$short  =~ s/-/_/gs;
			$short  =~ s/\s/_/gs;
			$short  =~ s/\W//gs;

			# Insert the short name
			$database->Quick("UPDATE Puppet
				SET PuppetShort=?
				WHERE PuppetName=?
				  AND PuppetPool=?",

			  $short,
			  $res->{'PuppetName'},
			  $res->{'PuppetPool'}
			 );
		}

		# Finish off
		$statement->finish();



		# Realm handler
		print "\n--REALM--\n\n";

		# Look for entries without short names
		$database->Pull(\$statement, "SELECT
			  RealmName AS \"RealmName\"
			FROM Realm
			WHERE RealmShort IS NULL");

		# Loop through
		while ($res = $statement->fetchrow_hashref())
		{
			# Display
			print "    " . $res->{'RealmName'} . "\n";

			# Generate short name
			$short  =  lc($res->{'RealmName'});
			$short  =~ s/-/_/gs;
			$short  =~ s/\s/_/gs;
			$short  =~ s/\W//gs;

			# Insert the short name
			$database->Quick("UPDATE Realm
				SET RealmShort=?
				WHERE RealmName=?",

			  $short,
			  $res->{'RealmName'}
			 );
		}

		# Finish off
		$statement->finish();
	}

	# Otherwise warn
	else
	{
		# Simple useage instead of error
		print "Ethereal Realms short name handler command-line interface:\n";
		print "Usage: ./short.pl {schema}\n\n";
	}


#################################################################################
# Sub-Routines
#################################################################################
